/*!
* Copyright Adaptavist 2022 (c) All rights reserved
*/
import { JsonType, PagedLink, SelfLink } from './Common';
import { User } from './User';
export interface QueueSettings {
    queueCount: {
        includeQueueCount: boolean;
        useCachedQueueCount: boolean;
    };
    _links: {
        self: string;
    };
}
export interface PagedOfQueue {
    _expands?: string[];
    size?: number;
    start?: number;
    limit?: number;
    isLastPage?: boolean;
    _links?: PagedLink;
    values?: Queue[];
}
export interface Queue {
    id?: string;
    name?: string;
    jql?: string;
    fields?: string[];
    issueCount?: number;
    _links?: SelfLink;
}
export interface PagedOfIssue {
    _expands?: string[];
    size?: number;
    start?: number;
    limit?: number;
    isLastPage?: boolean;
    _links?: PagedLink;
    values?: Issue[];
}
export interface Issue {
    expand?: string;
    id?: string;
    self?: string;
    key?: string;
    fields?: {
        [k: string]: any;
    };
    renderedFields?: {
        [k: string]: any;
    };
    properties?: {
        properties?: {
            [k: string]: string;
        };
    };
    names?: {
        [k: string]: string;
    };
    schema?: {
        [k: string]: JsonType;
    };
    transitions?: Transition[];
    operations?: {
        linkGroups?: LinkGroup[];
    };
    editmeta?: {
        fields?: {
            [k: string]: FieldMeta;
        };
    };
    changelog?: Changelog;
    versionedRepresentations?: {
        [k: string]: {
            [k: string]: any;
        };
    };
    fieldsToInclude?: {
        [k: string]: any;
    };
}
export interface Transition {
    id?: string;
    name?: string;
    to?: Status;
    fields?: {
        [k: string]: FieldMeta;
    };
    expand?: string;
}
export interface Status {
    self?: string;
    statusColor?: string;
    description?: string;
    iconUrl?: string;
    name?: string;
    id?: string;
    statusCategory?: StatusCategory;
}
export interface StatusCategory {
    self?: string;
    id?: number;
    key?: string;
    colorName?: string;
    name?: string;
}
export interface FieldMeta {
    required: boolean;
    schema?: JsonType;
    name?: string;
    fieldId?: string;
    autoCompleteUrl?: string;
    hasDefaultValue?: boolean;
    operations?: string[];
    allowedValues?: unknown[];
    defaultValue?: unknown;
}
export interface LinkGroup {
    id?: string;
    styleClass?: string;
    header?: SimpleLink;
    weight?: number;
    links?: SimpleLink[];
    groups?: LinkGroup[];
}
export interface SimpleLink {
    id?: string;
    styleClass?: string;
    iconClass?: string;
    label?: string;
    title?: string;
    href?: string;
    weight?: number;
}
export interface Changelog {
    startAt?: number;
    maxResults?: number;
    total?: number;
    histories?: ChangeHistory[];
}
export interface ChangeHistory {
    id?: string;
    author?: User;
    created?: string;
    items?: ChangeItem[];
    historyMetadata?: HistoryMetadata;
}
export interface ChangeItem {
    field?: string;
    fieldtype?: string;
    from?: string;
    fromString?: string;
    to?: string;
    toString?: string;
}
export interface HistoryMetadata {
    type?: string;
    description?: string;
    descriptionKey?: string;
    activityDescription?: string;
    activityDescriptionKey?: string;
    emailDescription?: string;
    emailDescriptionKey?: string;
    actor?: HistoryMetadataParticipant;
    generator?: HistoryMetadataParticipant;
    cause?: HistoryMetadataParticipant;
    extraData?: {
        [k: string]: string;
    };
}
export interface HistoryMetadataParticipant {
    id?: string;
    displayName?: string;
    displayNameKey?: string;
    type?: string;
    avatarUrl?: string;
    url?: string;
}
//# sourceMappingURL=Queue.d.ts.map