/*!
* Copyright Adaptavist 2022 (c) All rights reserved
*/
import { Headers, Response, BaseApiCore, ErrorStrategyOptionType, PlatformImplementation } from '@managed-api/commons-core';
import { CustomError } from './common';
import { CommonError, ErrorStrategyHandlers, ErrorStrategyOption } from './errorStrategy';
import { ErrorStrategyBuilder } from './builders/errorStrategy';
import { CreateCustomerRequest, CreateCustomerResponseOK } from './types/customer';
import { GetInfoRequest, GetInfoResponseOK } from './types/info';
import { GetPortalByIdRequest, GetPortalByIdResponseOK, GetPortalByKeyRequest, GetPortalByKeyResponseOK, GetPortalsRequest, GetPortalsResponseOK } from './types/portal';
import { GetQueueSettingsRequest, GetQueueSettingsResponseOK, SetQueuesIncludeCountGlobalRequest, SetQueuesIncludeCountGlobalResponseOK, SetQueuesIncludeCountOnProjectRequest, SetQueuesIncludeCountOnProjectResponseOK, SetQueuesUseCountCacheGlobalRequest, SetQueuesUseCountCacheGlobalResponseOK, SetQueuesUseCountCacheOnProjectRequest, SetQueuesUseCountCacheOnProjectResponseOK } from './types/queue';
import { CreateOrganizationRequest, CreateOrganizationResponseOK, DeleteOrganizationRequest, DeleteOrganizationResponseOK, GetOrganizationRequest, GetOrganizationResponseOK, GetOrganizationsRequest, GetOrganizationsResponseOK } from './types/organization';
import { AddOrganizationUsersRequest, AddOrganizationUsersResponseOK, GetOrganizationUsersRequest, GetOrganizationUsersResponseOK, RemoveOrganizationUsersRequest, RemoveOrganizationUsersResponseOK } from './types/organization/user';
import { CreateRequestRequest, CreateRequestResponseOK, GetRequestRequest, GetRequestResponseOK, GetRequestsRequest, GetRequestsResponseOK } from './types/request';
import { AnswerRequestApprovalRequest, AnswerRequestApprovalResponseOK, GetRequestApprovalRequest, GetRequestApprovalResponseOK, GetRequestApprovalsRequest, GetRequestApprovalsResponseOK } from './types/request/approval';
import { CreateRequestAttachmentRequest, CreateRequestAttachmentResponseOK } from './types/request/attachment';
import { CreateRequestCommentRequest, CreateRequestCommentResponseOK, GetRequestCommentRequest, GetRequestCommentResponseOK, GetRequestCommentsRequest, GetRequestCommentsResponseOK } from './types/request/comment';
import { AddRequestParticipantsRequest, AddRequestParticipantsResponseOK, GetRequestParticipantsRequest, GetRequestParticipantsResponseOK, RemoveRequestParticipantsRequest, RemoveRequestParticipantsResponseOK } from './types/request/participant';
import { GetSLAInfoByIdRequest, GetSLAInfoByIdResponseOK, GetSLAInfoRequest, GetSLAInfoResponseOK } from './types/request/SLA';
import { GetRequestStatusRequest, GetRequestStatusResponseOK } from './types/request/status';
import { GetRequestTransitionsRequest, GetRequestTransitionsResponseOK, PerformRequestTransitionRequest, PerformRequestTransitionResponseOK } from './types/request/transition';
import { AddTemporaryFileToServicedeskRequest, AddTemporaryFileToServicedeskResponseOK, GetServicedeskRequest, GetServicedeskResponseOK, GetServicedesksRequest, GetServicedesksResponseOK } from './types/servicedesk';
import { AddCustomersToServicedeskRequest, AddCustomersToServicedeskResponseOK } from './types/servicedesk/customer';
import { AddServicedeskOrganizationRequest, AddServicedeskOrganizationResponseOK, GetServicedeskOrganizationsRequest, GetServicedeskOrganizationsResponseOK, RemoveServicedeskOrganizationRequest, RemoveServicedeskOrganizationResponseOK } from './types/servicedesk/organization';
import { CreateServicedeckQueueRequest, CreateServicedeckQueueResponseOK, DeleteServicedeckQueueRequest, DeleteServicedeckQueueResponseOK, GetServicedeckQueueRequest, GetServicedeckQueueResponseOK, GetServicedeckQueuesRequest, GetServicedeckQueuesResponseOK, GetServicedeskIssuesInQueueRequest, GetServicedeskIssuesInQueueResponseOK, ReorderServicedeckQueueRequest, ReorderServicedeckQueueResponseOK, UpdateServicedeckQueueRequest, UpdateServicedeckQueueResponseOK } from './types/servicedesk/queue';
import { GetServicedeskRequestTypesRequest, GetServicedeskRequestTypesResponseOK, CreateServicedeskRequestTypeResponseOK, CreateServicedeskRequestTypeRequest, GetServicedeskRequestTypeResponseOK, GetServicedeskRequestTypeRequest, GetServicedeskRequestTypeFieldsRequest, GetServicedeskRequestTypeFieldsResponseOK, GetServicedeskRequestTypeGroupsResponseOK, GetServicedeskRequestTypeGroupsRequest } from './types/servicedesk/request/type';
export interface JiraServiceManagementOnPremiseApiCoreOptions extends ErrorStrategyOption {
}
declare type GetGlobalErrorStrategy = () => ErrorStrategyOptionType<CommonError, CustomError, ErrorStrategyHandlers, ErrorStrategyBuilder> | undefined;
export declare abstract class JiraServiceManagementOnPremiseApiCore extends BaseApiCore {
    private options?;
    Customer: CustomerGroup;
    Info: InfoGroup;
    Organization: OrganizationGroup;
    Portal: PortalGroup;
    Queue: QueueGroup;
    Request: RequestGroup;
    Servicedesk: ServicedeskGroup;
    All: AllGroup;
    constructor(options?: JiraServiceManagementOnPremiseApiCoreOptions);
    setGlobalErrorStrategy(errorStrategy: ErrorStrategyOptionType<CommonError, CustomError, ErrorStrategyHandlers, ErrorStrategyBuilder>): void;
    protected buildResponse(url: string, status: number, statusText: string, headers: Headers, body?: string | ArrayBuffer): Response<any>;
    private getGlobalErrorStrategy;
}
declare class AllGroup {
    private Customer;
    private Info;
    private Organization;
    private Portal;
    private Queue;
    private Request;
    private Servicedesk;
    constructor(Customer: CustomerGroup, Info: InfoGroup, Organization: OrganizationGroup, Portal: PortalGroup, Queue: QueueGroup, Request: RequestGroup, Servicedesk: ServicedeskGroup);
    /**
     * Creates a customer that is not associated with a service project.
     * The customer's username is their email address. They can set a password by clicking "Forgotten your password" on the portal login screen, or a Jira administrator can set one in User Management. By default, the customer can email requests to public service projects. If they have a password, they can also raise requests in customer portals that allow public signup. To raise requests in closed service projects, the customer must be added to a service project using Add customers.
     * This operation does not cause invitation email to be sent to the newly created customer.
     * Jira administrator global permission is required to create a customer.
     * Alternative usage: Customer.createCustomer
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/customer-createCustomer
     * @param options Request options.
     */
    createCustomer<T = CreateCustomerResponseOK>(options: CreateCustomerRequest): Promise<CreateCustomerResponseOK | T>;
    /**
     * Returns runtime information about Jira Service Management.
     * You do not need to be logged in to use this method.
     * Alternative usage: Customer.getInfo
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/info-getInfo
     * @param options Request options.
     */
    getInfo<T = GetInfoResponseOK>(options?: GetInfoRequest): Promise<GetInfoResponseOK | T>;
    /**
     * Get all portals. Returns a maximum of 50 portals per page
     * Alternative usage: Portal.getPortals
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/portals-getPortals
     * @param options Request options.
     */
    getPortals<T = GetPortalsResponseOK>(options?: GetPortalsRequest): Promise<GetPortalsResponseOK | T>;
    /**
     * Get a portal with the specified project key.
     * Alternative usage: Portal.getPortalByProjectKey
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/portals-getPortal
     * @param options Request options.
     */
    getPortalByProjectKey<T = GetPortalByKeyResponseOK>(options: GetPortalByKeyRequest): Promise<GetPortalByKeyResponseOK | T>;
    /**
     * Get a portal with the specified ID.
     * Alternative usage: Portal.getPortalById
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/portals-getPortal
     * @param options Request options.
     */
    getPortalById<T = GetPortalByIdResponseOK>(options: GetPortalByIdRequest): Promise<GetPortalByIdResponseOK | T>;
    /**
     * Get queue settings on project
     * Alternative usage: Queue.getQueueSettings
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/queues-getQueueSettingsOnProject
     * @param options Request options.
     */
    getQueueSettings<T = GetQueueSettingsResponseOK>(options: GetQueueSettingsRequest): Promise<GetQueueSettingsResponseOK | T>;
    /**
     * Set should queues use count cache on project
     * Alternative usage: Queue.setQueuesUseCountCacheOnProject
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/queues-setShouldQueuesUseCountCacheOnProject
     * @param options Request options.
     */
    setQueuesUseCountCacheOnProject<T = SetQueuesUseCountCacheOnProjectResponseOK>(options: SetQueuesUseCountCacheOnProjectRequest): Promise<SetQueuesUseCountCacheOnProjectResponseOK | T>;
    /**
     * Set should queues include count on project
     * Alternative usage: Queue.setQueuesIncludeCountOnProject
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/queues-setShouldQueuesIncludeCountOnProject
     * @param options Request options.
     */
    setQueuesIncludeCountOnProject<T = SetQueuesIncludeCountOnProjectResponseOK>(options: SetQueuesIncludeCountOnProjectRequest): Promise<SetQueuesIncludeCountOnProjectResponseOK | T>;
    /**
     * Set should queues use count cache globally
     * Alternative usage: Queue.setQueuesUseCountCacheGlobal
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/queues-setShouldQueuesUseCountCacheGlobally
     * @param options Request options.
     */
    setQueuesUseCountCacheGlobal<T = SetQueuesUseCountCacheGlobalResponseOK>(options: SetQueuesUseCountCacheGlobalRequest): Promise<SetQueuesUseCountCacheGlobalResponseOK | T>;
    /**
     * Set should queues include count globally
     * Alternative usage: Queue.setQueuesIncludeCountGlobal
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/queues-setShouldQueuesIncludeCountGlobally
     * @param options Request options.
     */
    setQueuesIncludeCountGlobal<T = SetQueuesIncludeCountGlobalResponseOK>(options: SetQueuesIncludeCountGlobalRequest): Promise<SetQueuesIncludeCountGlobalResponseOK | T>;
    /**
     * To create an organization Jira administrator global permission or agent permission is required depending on the settings
     * Alternative usage: Organization.createOrganization
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/organization-createOrganization
     * @param options Request options.
     */
    createOrganization<T = CreateOrganizationResponseOK>(options: CreateOrganizationRequest): Promise<CreateOrganizationResponseOK | T>;
    /**
     * Returns a list of organizations in the Jira instance.
     * If the user is not an agent, the resource returns a list of organizations the user is a member of.
     * Alternative usage: Organization.getOrganizations
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/organization-getOrganizations
     * @param options Request options.
     */
    getOrganizations<T = GetOrganizationsResponseOK>(options?: GetOrganizationsRequest): Promise<GetOrganizationsResponseOK | T>;
    /**
     * Returns an organization for a given organization ID.
     * Alternative usage: Organization.getOrganization
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/organization-getOrganization
     * @param options Request options.
     */
    getOrganization<T = GetOrganizationResponseOK>(options: GetOrganizationRequest): Promise<GetOrganizationResponseOK | T>;
    /**
     * Deletes an organization for a given organization ID.
     * Alternative usage: Organization.deleteOrganization
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/organization-deleteOrganization
     * @param options Request options.
     */
    deleteOrganization<T = DeleteOrganizationResponseOK>(options: DeleteOrganizationRequest): Promise<DeleteOrganizationResponseOK | T>;
    /**
     * Returns all the users of a specified organization.
     * Alternative usage: Organization.User.getUsers
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/organization-getUsersInOrganization
     * @param options Request options.
     */
    getOrganizationUsers<T = GetOrganizationUsersResponseOK>(options: GetOrganizationUsersRequest): Promise<GetOrganizationUsersResponseOK | T>;
    /**
     * Adds users to an organization.
     * Alternative usage: Organization.User.addUsers
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/organization-addUsersToOrganization
     * @param options Request options.
     */
    addOrganizationUsers<T = AddOrganizationUsersResponseOK>(options: AddOrganizationUsersRequest): Promise<AddOrganizationUsersResponseOK | T>;
    /**
     * Removes users from an organization.
     * Alternative usage: Organization.User.removeUsers
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/organization-removeUsersFromOrganization
     * @param options Request options.
     */
    removeOrganizationUsers<T = RemoveOrganizationUsersResponseOK>(options: RemoveOrganizationUsersRequest): Promise<RemoveOrganizationUsersResponseOK | T>;
    /**
     * Creates a customer request in a service project.
     * The service project and request type are required.
     * The fields that are mandatory for the request type are also required. If you need the list of the fields required for the request type, you can get it via this resource:
     * https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/requesttype/{requestTypeId}/field
     * Alternative usage: Request.createRequest
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request-createCustomerRequest
     * @param options Request options.
     */
    createRequest<T = CreateRequestResponseOK>(options: CreateRequestRequest): Promise<CreateRequestResponseOK | T>;
    /**
     * Returns all customer requests for the user that is executing the query.
     * That is, the customer requests where the user is the creator of the customer request or has participated in the customer request.
     * Returned customer requests are ordered chronologically by the latest activity on each customer request. For example, the latest status transition or comment.
     * Alternative usage: Request.getRequests
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request-getMyCustomerRequests
     * @param options Request options.
     */
    getRequests<T = GetRequestsResponseOK>(options?: GetRequestsRequest): Promise<GetRequestsResponseOK | T>;
    /**
     * Returns the customer request for a given request Id/key.
     * Alternative usage: Request.getRequest
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request-getCustomerRequestByIdOrKey
     * @param options Request options.
     */
    getRequest<T = GetRequestResponseOK>(options: GetRequestRequest): Promise<GetRequestResponseOK | T>;
    /**
     * Returns all approvals on a request, for a given request Id/key.
     * Alternative usage: Request.Approval.getApprovals
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request/{issueIdOrKey}/approval-getApprovals
     * @param options Request options.
     */
    getRequestApprovals<T = GetRequestApprovalsResponseOK>(options: GetRequestApprovalsRequest): Promise<GetRequestApprovalsResponseOK | T>;
    /**
     * Answer a pending approval.
     * Alternative usage: Request.Approval.answerApproval
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request/{issueIdOrKey}/approval-answerApproval
     * @param options Request options.
     */
    answerRequestApproval<T = AnswerRequestApprovalResponseOK>(options: AnswerRequestApprovalRequest): Promise<AnswerRequestApprovalResponseOK | T>;
    /**
     * Returns an approval for a given approval ID.
     * Alternative usage: Request.Approval.getApproval
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request/{issueIdOrKey}/approval-getApprovalById
     * @param options Request options.
     */
    getRequestApproval<T = GetRequestApprovalResponseOK>(options: GetRequestApprovalRequest): Promise<GetRequestApprovalResponseOK | T>;
    /**
     * Adds one or more temporary attachments that were created using Attach temporary file to a customer request. The attachment visibility is set by the public field.
     * Setting attachment visibility is dependent on the user's permission.
     * For example, Agents can create either public or internal attachments, while Unlicensed users can only create internal attachments, and Customers can only create public attachments.
     * An additional comment may be provided which will be prepended to the attachments.
     * Alternative usage: Request.Attachment.createAttachment
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request/{issueIdOrKey}/attachment-createAttachment
     * @param options Request options.
     */
    createRequestAttachment<T = CreateRequestAttachmentResponseOK>(options: CreateRequestAttachmentRequest): Promise<CreateRequestAttachmentResponseOK | T>;
    /**
     * Returns all comments on a customer request, for a given request Id/key.
     * Alternative usage: Request.Comment.getComments
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request/{issueIdOrKey}/comment-getRequestComments
     * @param options Request options.
     */
    getRequestComments<T = GetRequestCommentsResponseOK>(options: GetRequestCommentsRequest): Promise<GetRequestCommentsResponseOK | T>;
    /**
     * Creates a public or internal comment on an existing customer request.
     * The currently logged-in user will be the author of the comment.
     * The comment visibility is set by the public field.
     * Alternative usage: Request.Comment.createComment
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request/{issueIdOrKey}/comment-createRequestComment
     * @param options Request options.
     */
    createRequestComment<T = CreateRequestCommentResponseOK>(options: CreateRequestCommentRequest): Promise<CreateRequestCommentResponseOK | T>;
    /**
     * Returns a specific comment of a specific customer request based on the provided comment ID.
     * Alternative usage: Request.Comment.getComment
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request/{issueIdOrKey}/comment-getRequestCommentById
     * @param options Request options.
     */
    getRequestComment<T = GetRequestCommentResponseOK>(options: GetRequestCommentRequest): Promise<GetRequestCommentResponseOK | T>;
    /**
     * Returns all users participating in a customer request, for a given request Id/key.
     * Alternative usage: Request.Participant.getParticipants
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request/{issueIdOrKey}/participant-getRequestParticipants
     * @param options Request options.
     */
    getRequestParticipants<T = GetRequestParticipantsResponseOK>(options: GetRequestParticipantsRequest): Promise<GetRequestParticipantsResponseOK | T>;
    /**
     * Adds users as participants to an existing customer request.
     * Note, you can also add participants when creating a request via the request resource, by using the requestParticipants field.
     * Alternative usage: Request.Participant.addParticipants
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request/{issueIdOrKey}/participant-addRequestParticipants
     * @param options Request options.
     */
    addRequestParticipants<T = AddRequestParticipantsResponseOK>(options: AddRequestParticipantsRequest): Promise<AddRequestParticipantsResponseOK | T>;
    /**
     * Removes participants from an existing customer request.
     * Alternative usage: Request.Participant.removeParticipants
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request/{issueIdOrKey}/participant-removeRequestParticipants
     * @param options Request options.
     */
    removeRequestParticipants<T = RemoveRequestParticipantsResponseOK>(options: RemoveRequestParticipantsRequest): Promise<RemoveRequestParticipantsResponseOK | T>;
    /**
     * Returns the SLA information for a customer request for a given request Id/key.
     * A request can have zero or more SLA values.
     * Each SLA value can have zero or more "completed cycles" and zero or 1 "ongoing cycles".
     * Each cycle has information on when it started and stopped, and whether it breached the SLA goal.
     * Alternative usage: Request.SLA.getInfo
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request/{issueIdOrKey}/sla-getSlaInformation
     * @param options Request options.
     */
    getSLAInfo<T = GetSLAInfoResponseOK>(options: GetSLAInfoRequest): Promise<GetSLAInfoResponseOK | T>;
    /**
     * Returns the SLA information for a customer request for a given request Id/key and SLA metric Id.
     * A request can have zero or more SLA values.
     * Each SLA value can have zero or more "completed cycles" and zero or 1 "ongoing cycles".
     * Each cycle has information on when it started and stopped, and whether it breached the SLA goal.
     * Alternative usage: Request.SLA.getInfoById
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request/{issueIdOrKey}/sla-getSlaInformationById
     * @param options Request options.
     */
    getSLAInfoById<T = GetSLAInfoByIdResponseOK>(options: GetSLAInfoByIdRequest): Promise<GetSLAInfoByIdResponseOK | T>;
    /**
     * Returns the status transitions for a customer request for a given request Id/key.
     * The status transitions are returned in chronological order.
     * Alternative usage: Request.Status.getStatus
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request/{issueIdOrKey}/status-getCustomerRequestStatus
     * @param options Request options.
     */
    getRequestStatus<T = GetRequestStatusResponseOK>(options: GetRequestStatusRequest): Promise<GetRequestStatusResponseOK | T>;
    /**
     * Returns a list of transitions that customers can perform on the request.
     * Alternative usage: Request.Transition.getTransitions
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request/{issueIdOrKey}/transition-getCustomerTransitions
     * @param options Request options.
     */
    getRequestTransitions<T = GetRequestTransitionsResponseOK>(options: GetRequestTransitionsRequest): Promise<GetRequestTransitionsResponseOK | T>;
    /**
     * Perform a customer transition for a given request and transition ID.
     * An optional comment can be included to provide a reason for the transition.
     * Alternative usage: Request.Transition.performTransition
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request/{issueIdOrKey}/transition-performCustomerTransition
     * @param options Request options.
     */
    performRequestTransition<T = PerformRequestTransitionResponseOK>(options: PerformRequestTransitionRequest): Promise<PerformRequestTransitionResponseOK | T>;
    /**
     * Returns all service projects in the Jira Service Management application with the option to include archived service projects.
     * Alternative usage: Servicedesk.getServicedesks
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk-getServiceDesks
     * @param options Request options.
     */
    getServicedesks<T = GetServicedesksResponseOK>(options?: GetServicedesksRequest): Promise<GetServicedesksResponseOK | T>;
    /**
     * Returns the service project for a given service project Id.
     * Alternative usage: Servicedesk.getServicedesk
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk-getServiceDeskById
     * @param options Request options.
     */
    getServicedesk<T = GetServicedeskResponseOK>(options: GetServicedeskRequest): Promise<GetServicedeskResponseOK | T>;
    /**
     * Create one or more temporary attachments, which can later be converted into permanent attachments on Create attachment:
     * https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request/{issueIdOrKey}/attachment
     * On successful execution, this resource will return a list of temporary attachment IDs, which are used in subsequent calls to convert the attachments into permanent attachments.
     * Alternative usage: Servicedesk.addTemporaryFile
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/attachTemporaryFile-attachTemporaryFile
     * @param options Request options.
     */
    addTemporaryFileToServicedesk<T = AddTemporaryFileToServicedeskResponseOK>(options: AddTemporaryFileToServicedeskRequest): Promise<AddTemporaryFileToServicedeskResponseOK | T>;
    /**
     * Adds one or more existing customers to the given service project. If you need to create a customer, see Create customer:
     * https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/customer
     * Administer project permission is required, or agents if public signups and invites are enabled for the service project.
     * Alternative usage: Servicedesk.Customer.addCustomers
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/customer-addCustomers
     * @param options Request options.
     */
    addCustomersToServicedesk<T = AddCustomersToServicedeskResponseOK>(options: AddCustomersToServicedeskRequest): Promise<AddCustomersToServicedeskResponseOK | T>;
    /**
     * Adds an organization to a service project for a given service project id and organization id.
     * Alternative usage: Servicedesk.Organization.addOrganization
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/organization-addOrganization
     * @param options Request options.
     */
    addServicedeskOrganization<T = AddServicedeskOrganizationResponseOK>(options: AddServicedeskOrganizationRequest): Promise<AddServicedeskOrganizationResponseOK | T>;
    /**
     * Removes an organization from a service project for a given service project id and organization id.
     * Alternative usage: Servicedesk.Organization.removeOrganization
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/organization-removeOrganization
     * @param options Request options.
     */
    removeServicedeskOrganization<T = RemoveServicedeskOrganizationResponseOK>(options: RemoveServicedeskOrganizationRequest): Promise<RemoveServicedeskOrganizationResponseOK | T>;
    /**
     * Returns all organizations within a service project for a given service project id.
     * Alternative usage: Servicedesk.Organization.getOrganizations
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/organization-getOrganizations
     * @param options Request options.
     */
    getServicedeskOrganizations<T = GetServicedeskOrganizationsResponseOK>(options: GetServicedeskOrganizationsRequest): Promise<GetServicedeskOrganizationsResponseOK | T>;
    /**
     * Returns a page of queues defined inside a service project, for a given service project ID.
     * The returned queues will include an issue count for each queue (represented in issueCount field) if the query param includeCount is set to true (defaults to false).
     * Alternative usage: Servicedesk.Queue.getQueues
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/queue-getQueues
     * @param options Request options.
     */
    getServicedeckQueues<T = GetServicedeckQueuesResponseOK>(options: GetServicedeckQueuesRequest): Promise<GetServicedeckQueuesResponseOK | T>;
    /**
     * Creates a queue with the given properties.
     * Alternative usage: Servicedesk.Queue.createQueue
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/queue-createQueue
     * @param options Request options.
     */
    createServicedeckQueue<T = CreateServicedeckQueueResponseOK>(options: CreateServicedeckQueueRequest): Promise<CreateServicedeckQueueResponseOK | T>;
    /**
     * Reorder queues for the users. This is the order in which the queues will appear in agent view.
     * The API requires all queue ids to be passed in the new order.
     * Alternative usage: Servicedesk.Queue.reorderQueues
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/queue-reorderQueues
     * @param options Request options.
     */
    reorderServicedeckQueue<T = ReorderServicedeckQueueResponseOK>(options: ReorderServicedeckQueueRequest): Promise<ReorderServicedeckQueueResponseOK | T>;
    /**
     * Updates the queue properties with the new properties. If a property is not passed it will not be updated.
     * Alternative usage: Servicedesk.Queue.updateQueue
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/queue-updateQueue
     * @param options Request options.
     */
    updateServicedeckQueue<T = UpdateServicedeckQueueResponseOK>(options: UpdateServicedeckQueueRequest): Promise<UpdateServicedeckQueueResponseOK | T>;
    /**
     * Delete the queue for the given queue id.
     * Alternative usage: Servicedesk.Queue.deleteQueue
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/queue-deleteQueue
     * @param options Request options.
     */
    deleteServicedeckQueue<T = DeleteServicedeckQueueResponseOK>(options: DeleteServicedeckQueueRequest): Promise<DeleteServicedeckQueueResponseOK | T>;
    /**
     * Returns the queue for a given service project id and queue id.
     * The returned queue will include an issue count for queue (represented in issueCount field) if the query param includeCount is set to true (defaults to false).
     * Alternative usage: Servicedesk.Queue.getQueue
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/queue-getQueue
     * @param options Request options.
     */
    getServicedeckQueue<T = GetServicedeckQueueResponseOK>(options: GetServicedeckQueueRequest): Promise<GetServicedeckQueueResponseOK | T>;
    /**
     * Returns a page of issues inside a queue for a given queue ID.
     * Only fields that the queue is configured to show are returned. For example, if a queue is configured to show only Description and Due Date, then only those two fields are returned for each issue in the queue.
     * Alternative usage: Servicedesk.Queue.getIssuesInQueue
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/queue-getIssuesInQueue
     * @param options Request options.
     */
    getServicedeskIssuesInQueue<T = GetServicedeskIssuesInQueueResponseOK>(options: GetServicedeskIssuesInQueueRequest): Promise<GetServicedeskIssuesInQueueResponseOK | T>;
    /**
     * Returns all request types from a service project, for a given service project Id.
     * Alternative usage: Servicedesk.Request.Type.getTypes
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/requesttype-getRequestTypes
     * @param options Request options.
     */
    getServicedeskRequestTypes<T = GetServicedeskRequestTypesResponseOK>(options: GetServicedeskRequestTypesRequest): Promise<GetServicedeskRequestTypesResponseOK | T>;
    /**
     * Creates a new request type for a given service project.
     * Certain fields cannot be specified on creation. These fields are given default values instead, as shown below.
     * Request Type icon - Question mark icon
     * Request Type groups - Empty, i.e. this request type will be hidden by default and not visible on the customer portal
     * Request Type status mapping - Empty, i.e. no custom status mapping
     * Request Type field mapping - Show the required fields as specified by the issue type
     * These fields can be updated after creation by a project administrator using the Agent view.
     * Alternative usage: Servicedesk.Request.Type.createType
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/requesttype-createRequestType
     * @param options Request options.
     */
    createServicedeskRequestType<T = CreateServicedeskRequestTypeResponseOK>(options: CreateServicedeskRequestTypeRequest): Promise<CreateServicedeskRequestTypeResponseOK | T>;
    /**
     * Returns a request type for a given request type Id.
     * Alternative usage: Servicedesk.Request.Type.getType
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/requesttype-getRequestTypeById
     * @param options Request options.
     */
    getServicedeskRequestType<T = GetServicedeskRequestTypeResponseOK>(options: GetServicedeskRequestTypeRequest): Promise<GetServicedeskRequestTypeResponseOK | T>;
    /**
     * Returns the fields for a request type, for a given request type Id and service project Id. These are the fields that are required to create a customer request of that particular request type.
     * In addition, the following information about the current user's permissions for the request type is returned:
     * * canRaiseOnBehalfOf field - Returns true, if the user has permission to raise requests on behalf of customers. Otherwise, returns false.
     * * canAddRequestParticipants field - Returns true, if the user can add request participants. Otherwise, returns false.
     * Alternative usage: Servicedesk.Request.Type.getFields
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/requesttype/{requestTypeId}/field-getRequestTypeFields
     * @param options Request options.
     */
    getServicedeskRequestTypeFields<T = GetServicedeskRequestTypeFieldsResponseOK>(options: GetServicedeskRequestTypeFieldsRequest): Promise<GetServicedeskRequestTypeFieldsResponseOK | T>;
    /**
     * Returns all request type groups from a service project, for a given service project Id.
     * The groups will be in the same order as the order in which they appear on the customer portal
     * Alternative usage: Servicedesk.Request.Type.getTypeGroups
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/requesttypegroup-getRequestTypeGroups
     * @param options Request options.
     */
    getServicedeskRequestTypeGroups<T = GetServicedeskRequestTypeGroupsResponseOK>(options: GetServicedeskRequestTypeGroupsRequest): Promise<GetServicedeskRequestTypeGroupsResponseOK | T>;
}
declare class CustomerGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Creates a customer that is not associated with a service project.
     * The customer's username is their email address. They can set a password by clicking "Forgotten your password" on the portal login screen, or a Jira administrator can set one in User Management. By default, the customer can email requests to public service projects. If they have a password, they can also raise requests in customer portals that allow public signup. To raise requests in closed service projects, the customer must be added to a service project using Add customers.
     * This operation does not cause invitation email to be sent to the newly created customer.
     * Jira administrator global permission is required to create a customer.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/customer-createCustomer
     * @param options Request options.
     */
    createCustomer<T = CreateCustomerResponseOK>(options: CreateCustomerRequest): Promise<CreateCustomerResponseOK | T>;
}
declare class InfoGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Returns runtime information about Jira Service Management.
     * You do not need to be logged in to use this method.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/info-getInfo
     * @param options Request options.
     */
    getInfo<T = GetInfoResponseOK>(options?: GetInfoRequest): Promise<GetInfoResponseOK | T>;
}
declare class PortalGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Get all portals. Returns a maximum of 50 portals per page
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/portals-getPortals
     * @param options Request options.
     */
    getPortals<T = GetPortalsResponseOK>(options?: GetPortalsRequest): Promise<GetPortalsResponseOK | T>;
    /**
     * Get a portal with the specified project key.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/portals-getPortal
     * @param options Request options.
     */
    getPortalByProjectKey<T = GetPortalByKeyResponseOK>(options: GetPortalByKeyRequest): Promise<GetPortalByKeyResponseOK | T>;
    /**
     * Get a portal with the specified ID.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/portals-getPortal
     * @param options Request options.
     */
    getPortalById<T = GetPortalByIdResponseOK>(options: GetPortalByIdRequest): Promise<GetPortalByIdResponseOK | T>;
}
declare class QueueGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Get queue settings on project
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/queues-getQueueSettingsOnProject
     * @param options Request options.
     */
    getQueueSettings<T = GetQueueSettingsResponseOK>(options: GetQueueSettingsRequest): Promise<GetQueueSettingsResponseOK | T>;
    /**
     * Set should queues use count cache on project
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/queues-setShouldQueuesUseCountCacheOnProject
     * @param options Request options.
     */
    setQueuesUseCountCacheOnProject<T = SetQueuesUseCountCacheOnProjectResponseOK>(options: SetQueuesUseCountCacheOnProjectRequest): Promise<SetQueuesUseCountCacheOnProjectResponseOK | T>;
    /**
     * Set should queues include count on project
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/queues-setShouldQueuesIncludeCountOnProject
     * @param options Request options.
     */
    setQueuesIncludeCountOnProject<T = SetQueuesIncludeCountOnProjectResponseOK>(options: SetQueuesIncludeCountOnProjectRequest): Promise<SetQueuesIncludeCountOnProjectResponseOK | T>;
    /**
     * Set should queues use count cache globally
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/queues-setShouldQueuesUseCountCacheGlobally
     * @param options Request options.
     */
    setQueuesUseCountCacheGlobal<T = SetQueuesUseCountCacheGlobalResponseOK>(options: SetQueuesUseCountCacheGlobalRequest): Promise<SetQueuesUseCountCacheGlobalResponseOK | T>;
    /**
     * Set should queues include count globally
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/queues-setShouldQueuesIncludeCountGlobally
     * @param options Request options.
     */
    setQueuesIncludeCountGlobal<T = SetQueuesIncludeCountGlobalResponseOK>(options: SetQueuesIncludeCountGlobalRequest): Promise<SetQueuesIncludeCountGlobalResponseOK | T>;
}
declare class OrganizationGroup {
    private implementation;
    private getGlobalErrorStrategy;
    User: OrganizationUserGroup;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * To create an organization Jira administrator global permission or agent permission is required depending on the settings
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/organization-createOrganization
     * @param options Request options.
     */
    createOrganization<T = CreateOrganizationResponseOK>(options: CreateOrganizationRequest): Promise<CreateOrganizationResponseOK | T>;
    /**
     * Returns a list of organizations in the Jira instance.
     * If the user is not an agent, the resource returns a list of organizations the user is a member of.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/organization-getOrganizations
     * @param options Request options.
     */
    getOrganizations<T = GetOrganizationsResponseOK>(options?: GetOrganizationsRequest): Promise<GetOrganizationsResponseOK | T>;
    /**
     * Returns an organization for a given organization ID.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/organization-getOrganization
     * @param options Request options.
     */
    getOrganization<T = GetOrganizationResponseOK>(options: GetOrganizationRequest): Promise<GetOrganizationResponseOK | T>;
    /**
     * Deletes an organization for a given organization ID.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/organization-deleteOrganization
     * @param options Request options.
     */
    deleteOrganization<T = DeleteOrganizationResponseOK>(options: DeleteOrganizationRequest): Promise<DeleteOrganizationResponseOK | T>;
}
declare class OrganizationUserGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Returns all the users of a specified organization.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/organization-getUsersInOrganization
     * @param options Request options.
     */
    getUsers<T = GetOrganizationUsersResponseOK>(options: GetOrganizationUsersRequest): Promise<GetOrganizationUsersResponseOK | T>;
    /**
     * Adds users to an organization.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/organization-addUsersToOrganization
     * @param options Request options.
     */
    addUsers<T = AddOrganizationUsersResponseOK>(options: AddOrganizationUsersRequest): Promise<AddOrganizationUsersResponseOK | T>;
    /**
     * Removes users from an organization.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/organization-removeUsersFromOrganization
     * @param options Request options.
     */
    removeUsers<T = RemoveOrganizationUsersResponseOK>(options: RemoveOrganizationUsersRequest): Promise<RemoveOrganizationUsersResponseOK | T>;
}
declare class RequestGroup {
    private implementation;
    private getGlobalErrorStrategy;
    Approval: RequestApprovalGroup;
    Attachment: RequestAttachmentGroup;
    Comment: RequestCommentGroup;
    Participant: RequestParticipantGroup;
    SLA: RequestSLAGroup;
    Status: RequestStatusGroup;
    Transition: RequestTransitionGroup;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Creates a customer request in a service project.
     * The service project and request type are required.
     * The fields that are mandatory for the request type are also required. If you need the list of the fields required for the request type, you can get it via this resource:
     * https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/requesttype/{requestTypeId}/field
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request-createCustomerRequest
     * @param options Request options.
     */
    createRequest<T = CreateRequestResponseOK>(options: CreateRequestRequest): Promise<CreateRequestResponseOK | T>;
    /**
     * Returns all customer requests for the user that is executing the query.
     * That is, the customer requests where the user is the creator of the customer request or has participated in the customer request.
     * Returned customer requests are ordered chronologically by the latest activity on each customer request. For example, the latest status transition or comment.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request-getMyCustomerRequests
     * @param options Request options.
     */
    getRequests<T = GetRequestsResponseOK>(options?: GetRequestsRequest): Promise<GetRequestsResponseOK | T>;
    /**
     * Returns the customer request for a given request Id/key.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request-getCustomerRequestByIdOrKey
     * @param options Request options.
     */
    getRequest<T = GetRequestResponseOK>(options: GetRequestRequest): Promise<GetRequestResponseOK | T>;
}
declare class RequestApprovalGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Returns all approvals on a request, for a given request Id/key.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request/{issueIdOrKey}/approval-getApprovals
     * @param options Request options.
     */
    getApprovals<T = GetRequestApprovalsResponseOK>(options: GetRequestApprovalsRequest): Promise<GetRequestApprovalsResponseOK | T>;
    /**
     * Answer a pending approval.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request/{issueIdOrKey}/approval-answerApproval
     * @param options Request options.
     */
    answerApproval<T = AnswerRequestApprovalResponseOK>(options: AnswerRequestApprovalRequest): Promise<AnswerRequestApprovalResponseOK | T>;
    /**
     * Returns an approval for a given approval ID.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request/{issueIdOrKey}/approval-getApprovalById
     * @param options Request options.
     */
    getApproval<T = GetRequestApprovalResponseOK>(options: GetRequestApprovalRequest): Promise<GetRequestApprovalResponseOK | T>;
}
declare class RequestAttachmentGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Adds one or more temporary attachments that were created using Attach temporary file to a customer request. The attachment visibility is set by the public field.
     * Setting attachment visibility is dependent on the user's permission.
     * For example, Agents can create either public or internal attachments, while Unlicensed users can only create internal attachments, and Customers can only create public attachments.
     * An additional comment may be provided which will be prepended to the attachments.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request/{issueIdOrKey}/attachment-createAttachment
     * @param options Request options.
     */
    createAttachment<T = CreateRequestAttachmentResponseOK>(options: CreateRequestAttachmentRequest): Promise<CreateRequestAttachmentResponseOK | T>;
}
declare class RequestCommentGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Returns all comments on a customer request, for a given request Id/key.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request/{issueIdOrKey}/comment-getRequestComments
     * @param options Request options.
     */
    getComments<T = GetRequestCommentsResponseOK>(options: GetRequestCommentsRequest): Promise<GetRequestCommentsResponseOK | T>;
    /**
     * Creates a public or internal comment on an existing customer request.
     * The currently logged-in user will be the author of the comment.
     * The comment visibility is set by the public field.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request/{issueIdOrKey}/comment-createRequestComment
     * @param options Request options.
     */
    createComment<T = CreateRequestCommentResponseOK>(options: CreateRequestCommentRequest): Promise<CreateRequestCommentResponseOK | T>;
    /**
     * Returns a specific comment of a specific customer request based on the provided comment ID.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request/{issueIdOrKey}/comment-getRequestCommentById
     * @param options Request options.
     */
    getComment<T = GetRequestCommentResponseOK>(options: GetRequestCommentRequest): Promise<GetRequestCommentResponseOK | T>;
}
declare class RequestParticipantGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Returns all users participating in a customer request, for a given request Id/key.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request/{issueIdOrKey}/participant-getRequestParticipants
     * @param options Request options.
     */
    getParticipants<T = GetRequestParticipantsResponseOK>(options: GetRequestParticipantsRequest): Promise<GetRequestParticipantsResponseOK | T>;
    /**
     * Adds users as participants to an existing customer request.
     * Note, you can also add participants when creating a request via the request resource, by using the requestParticipants field.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request/{issueIdOrKey}/participant-addRequestParticipants
     * @param options Request options.
     */
    addParticipants<T = AddRequestParticipantsResponseOK>(options: AddRequestParticipantsRequest): Promise<AddRequestParticipantsResponseOK | T>;
    /**
     * Removes participants from an existing customer request.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request/{issueIdOrKey}/participant-removeRequestParticipants
     * @param options Request options.
     */
    removeParticipants<T = RemoveRequestParticipantsResponseOK>(options: RemoveRequestParticipantsRequest): Promise<RemoveRequestParticipantsResponseOK | T>;
}
declare class RequestSLAGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Returns the SLA information for a customer request for a given request Id/key.
     * A request can have zero or more SLA values.
     * Each SLA value can have zero or more "completed cycles" and zero or 1 "ongoing cycles".
     * Each cycle has information on when it started and stopped, and whether it breached the SLA goal.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request/{issueIdOrKey}/sla-getSlaInformation
     * @param options Request options.
     */
    getInfo<T = GetSLAInfoResponseOK>(options: GetSLAInfoRequest): Promise<GetSLAInfoResponseOK | T>;
    /**
     * Returns the SLA information for a customer request for a given request Id/key and SLA metric Id.
     * A request can have zero or more SLA values.
     * Each SLA value can have zero or more "completed cycles" and zero or 1 "ongoing cycles".
     * Each cycle has information on when it started and stopped, and whether it breached the SLA goal.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request/{issueIdOrKey}/sla-getSlaInformationById
     * @param options Request options.
     */
    getInfoById<T = GetSLAInfoByIdResponseOK>(options: GetSLAInfoByIdRequest): Promise<GetSLAInfoByIdResponseOK | T>;
}
declare class RequestStatusGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Returns the status transitions for a customer request for a given request Id/key.
     * The status transitions are returned in chronological order.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request/{issueIdOrKey}/status-getCustomerRequestStatus
     * @param options Request options.
     */
    getStatus<T = GetRequestStatusResponseOK>(options: GetRequestStatusRequest): Promise<GetRequestStatusResponseOK | T>;
}
declare class RequestTransitionGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Returns a list of transitions that customers can perform on the request.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request/{issueIdOrKey}/transition-getCustomerTransitions
     * @param options Request options.
     */
    getTransitions<T = GetRequestTransitionsResponseOK>(options: GetRequestTransitionsRequest): Promise<GetRequestTransitionsResponseOK | T>;
    /**
     * Perform a customer transition for a given request and transition ID.
     * An optional comment can be included to provide a reason for the transition.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request/{issueIdOrKey}/transition-performCustomerTransition
     * @param options Request options.
     */
    performTransition<T = PerformRequestTransitionResponseOK>(options: PerformRequestTransitionRequest): Promise<PerformRequestTransitionResponseOK | T>;
}
declare class ServicedeskGroup {
    private implementation;
    private getGlobalErrorStrategy;
    Request: ServicedeskRequestGroup;
    Customer: ServicedeskCustomerGroup;
    Organization: ServicedeskOrganizationGroup;
    Queue: ServicedeskQueueGroup;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Returns all service projects in the Jira Service Management application with the option to include archived service projects.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk-getServiceDesks
     * @param options Request options.
     */
    getServicedesks<T = GetServicedesksResponseOK>(options?: GetServicedesksRequest): Promise<GetServicedesksResponseOK | T>;
    /**
     * Returns the service project for a given service project Id.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk-getServiceDeskById
     * @param options Request options.
     */
    getServicedesk<T = GetServicedeskResponseOK>(options: GetServicedeskRequest): Promise<GetServicedeskResponseOK | T>;
    /**
     * Create one or more temporary attachments, which can later be converted into permanent attachments on Create attachment:
     * https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request/{issueIdOrKey}/attachment
     * On successful execution, this resource will return a list of temporary attachment IDs, which are used in subsequent calls to convert the attachments into permanent attachments.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/attachTemporaryFile-attachTemporaryFile
     * @param options Request options.
     */
    addTemporaryFile<T = AddTemporaryFileToServicedeskResponseOK>(options: AddTemporaryFileToServicedeskRequest): Promise<AddTemporaryFileToServicedeskResponseOK | T>;
}
declare class ServicedeskCustomerGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Adds one or more existing customers to the given service project. If you need to create a customer, see Create customer:
     * https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/customer
     * Administer project permission is required, or agents if public signups and invites are enabled for the service project.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/customer-addCustomers
     * @param options Request options.
     */
    addCustomers<T = AddCustomersToServicedeskResponseOK>(options: AddCustomersToServicedeskRequest): Promise<AddCustomersToServicedeskResponseOK | T>;
}
declare class ServicedeskOrganizationGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Adds an organization to a service project for a given service project id and organization id.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/organization-addOrganization
     * @param options Request options.
     */
    addOrganization<T = AddServicedeskOrganizationResponseOK>(options: AddServicedeskOrganizationRequest): Promise<AddServicedeskOrganizationResponseOK | T>;
    /**
     * Removes an organization from a service project for a given service project id and organization id.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/organization-removeOrganization
     * @param options Request options.
     */
    removeOrganization<T = RemoveServicedeskOrganizationResponseOK>(options: RemoveServicedeskOrganizationRequest): Promise<RemoveServicedeskOrganizationResponseOK | T>;
    /**
     * Returns all organizations within a service project for a given service project id.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/organization-getOrganizations
     * @param options Request options.
     */
    getOrganizations<T = GetServicedeskOrganizationsResponseOK>(options: GetServicedeskOrganizationsRequest): Promise<GetServicedeskOrganizationsResponseOK | T>;
}
declare class ServicedeskQueueGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Returns a page of queues defined inside a service project, for a given service project ID.
     * The returned queues will include an issue count for each queue (represented in issueCount field) if the query param includeCount is set to true (defaults to false).
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/queue-getQueues
     * @param options Request options.
     */
    getQueues<T = GetServicedeckQueuesResponseOK>(options: GetServicedeckQueuesRequest): Promise<GetServicedeckQueuesResponseOK | T>;
    /**
     * Creates a queue with the given properties.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/queue-createQueue
     * @param options Request options.
     */
    createQueue<T = CreateServicedeckQueueResponseOK>(options: CreateServicedeckQueueRequest): Promise<CreateServicedeckQueueResponseOK | T>;
    /**
     * Reorder queues for the users. This is the order in which the queues will appear in agent view.
     * The API requires all queue ids to be passed in the new order.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/queue-reorderQueues
     * @param options Request options.
     */
    reorderQueues<T = ReorderServicedeckQueueResponseOK>(options: ReorderServicedeckQueueRequest): Promise<ReorderServicedeckQueueResponseOK | T>;
    /**
     * Updates the queue properties with the new properties. If a property is not passed it will not be updated.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/queue-updateQueue
     * @param options Request options.
     */
    updateQueue<T = UpdateServicedeckQueueResponseOK>(options: UpdateServicedeckQueueRequest): Promise<UpdateServicedeckQueueResponseOK | T>;
    /**
     * Delete the queue for the given queue id.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/queue-deleteQueue
     * @param options Request options.
     */
    deleteQueue<T = DeleteServicedeckQueueResponseOK>(options: DeleteServicedeckQueueRequest): Promise<DeleteServicedeckQueueResponseOK | T>;
    /**
     * Returns the queue for a given service project id and queue id.
     * The returned queue will include an issue count for queue (represented in issueCount field) if the query param includeCount is set to true (defaults to false).
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/queue-getQueue
     * @param options Request options.
     */
    getQueue<T = GetServicedeckQueueResponseOK>(options: GetServicedeckQueueRequest): Promise<GetServicedeckQueueResponseOK | T>;
    /**
     * Returns a page of issues inside a queue for a given queue ID.
     * Only fields that the queue is configured to show are returned. For example, if a queue is configured to show only Description and Due Date, then only those two fields are returned for each issue in the queue.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/queue-getIssuesInQueue
     * @param options Request options.
     */
    getIssuesInQueue<T = GetServicedeskIssuesInQueueResponseOK>(options: GetServicedeskIssuesInQueueRequest): Promise<GetServicedeskIssuesInQueueResponseOK | T>;
}
declare class ServicedeskRequestGroup {
    private implementation;
    private getGlobalErrorStrategy;
    Type: ServicedeskRequestTypeGroup;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
}
declare class ServicedeskRequestTypeGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Returns all request types from a service project, for a given service project Id.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/requesttype-getRequestTypes
     * @param options Request options.
     */
    getTypes<T = GetServicedeskRequestTypesResponseOK>(options: GetServicedeskRequestTypesRequest): Promise<GetServicedeskRequestTypesResponseOK | T>;
    /**
     * Creates a new request type for a given service project.
     * Certain fields cannot be specified on creation. These fields are given default values instead, as shown below.
     * Request Type icon - Question mark icon
     * Request Type groups - Empty, i.e. this request type will be hidden by default and not visible on the customer portal
     * Request Type status mapping - Empty, i.e. no custom status mapping
     * Request Type field mapping - Show the required fields as specified by the issue type
     * These fields can be updated after creation by a project administrator using the Agent view.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/requesttype-createRequestType
     * @param options Request options.
     */
    createType<T = CreateServicedeskRequestTypeResponseOK>(options: CreateServicedeskRequestTypeRequest): Promise<CreateServicedeskRequestTypeResponseOK | T>;
    /**
     * Returns a request type for a given request type Id.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/requesttype-getRequestTypeById
     * @param options Request options.
     */
    getType<T = GetServicedeskRequestTypeResponseOK>(options: GetServicedeskRequestTypeRequest): Promise<GetServicedeskRequestTypeResponseOK | T>;
    /**
     * Returns the fields for a request type, for a given request type Id and service project Id. These are the fields that are required to create a customer request of that particular request type.
     * In addition, the following information about the current user's permissions for the request type is returned:
     * * canRaiseOnBehalfOf field - Returns true, if the user has permission to raise requests on behalf of customers. Otherwise, returns false.
     * * canAddRequestParticipants field - Returns true, if the user can add request participants. Otherwise, returns false.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/requesttype/{requestTypeId}/field-getRequestTypeFields
     * @param options Request options.
     */
    getFields<T = GetServicedeskRequestTypeFieldsResponseOK>(options: GetServicedeskRequestTypeFieldsRequest): Promise<GetServicedeskRequestTypeFieldsResponseOK | T>;
    /**
     * Returns all request type groups from a service project, for a given service project Id.
     * The groups will be in the same order as the order in which they appear on the customer portal
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/requesttypegroup-getRequestTypeGroups
     * @param options Request options.
     */
    getTypeGroups<T = GetServicedeskRequestTypeGroupsResponseOK>(options: GetServicedeskRequestTypeGroupsRequest): Promise<GetServicedeskRequestTypeGroupsResponseOK | T>;
}
export {};
//# sourceMappingURL=index.d.ts.map