/*!
* Copyright Adaptavist 2022 (c) All rights reserved
*/
import { HeadersOption } from '@managed-api/commons-core';
import { CustomerRequest } from '../definitions/Customer';
import { PagedOfCustomerRequest } from '../definitions/Request';
import { CommonError, ErrorStrategyOption } from '../errorStrategy';
export interface CreateRequestRequest extends HeadersOption, ErrorStrategyOption {
    body: {
        serviceDeskId: string;
        requestTypeId: string;
        /**
         * The fields that are mandatory for the request type are also required.
         * If you need the list of the fields required for the request type, you can get it via this resource:
         * https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/requesttype/{requestTypeId}/field
         */
        requestFieldValues: {
            [k: string]: any;
        };
        /**
         * Not available to users who only have the Service Desk Customer permission or if the feature is turned off for customers.
         */
        requestParticipants?: string[];
        /**
         * Not available to users who only have the Service Desk Customer permission.
         */
        raiseOnBehalfOf?: string;
    };
}
export interface CreateRequestResponseOK extends CustomerRequest {
}
export interface CreateRequestResponseError extends CommonError {
}
export interface GetRequestsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Filters results to customer requests where the issue summary matches the searchTerm. You can use wildcards in the searchTerm.
     */
    searchTerm?: string;
    /**
     * Filters results to customer requests where the user is the creator and/or participant:
     * OWNED_REQUESTS - Only return customer requests where the user is the creator.
     * PARTICIPATED_REQUESTS - Only return customer requests where the user is a participant.
     * ALL_REQUESTS - Return customer requests where the user is the creator or a participant.
     */
    requestOwnership?: string;
    /**
     * Filters results to customer requests that are resolved, unresolved, or either of the two:
     * CLOSED_REQUESTS - Only return customer requests that are resolved.
     * OPEN_REQUESTS - Only return customer requests that are unresolved.
     * ALL_REQUESTS - Returns customer requests that are either resolved or unresolved.
     */
    requestStatus?: string;
    /**
     * Filters results to customer requests from a specific service project.
     */
    serviceDeskId?: number;
    /**
     * Filters results to customer requests of a specific request type.
     * You must also specify the serviceDeskID for the service desk that the request type belongs to.
     */
    requestTypeId?: number;
    /**
     * This is a multi-value parameter indicating which properties of the customer request to expand:
     * serviceDesk - Return additional details for each service project in the response.
     * requestType - Return additional details for each request type in the response.
     * participant - Return the participant details, if any, for each customer request in the response.
     * sla - Return the SLA information on the given request.
     * status - Return the status transitions, in chronological order, for each customer request in the response.
     */
    expand?: string;
    /**
     * The starting index of the returned objects. Base index: 0.
     */
    start?: number;
    /**
     * The maximum number of items to return per page. Default: 50.
     */
    limit?: number;
}
export interface GetRequestsResponseOK extends PagedOfCustomerRequest {
}
export interface GetRequestsResponseError extends CommonError {
}
export interface GetRequestRequest extends HeadersOption, ErrorStrategyOption {
    issueIdOrKey: string | number;
    /**
     * This is a multi-value parameter indicating which properties of the customer request to expand:
     * serviceDesk - Return additional details for each service project in the response.
     * requestType - Return additional details for each request type in the response.
     * participant - Return the participant details, if any, for each customer request in the response.
     * sla - Return the SLA information on the given request.
     * status - Return the status transitions, in chronological order, for each customer request in the response.
     */
    expand?: string;
}
export interface GetRequestResponseOK extends CustomerRequest {
}
export interface GetRequestResponseError extends CommonError {
}
//# sourceMappingURL=request.d.ts.map